<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Form Recipients /////////////////////////
// Buttons:
define('FORM_RECIPIENTS_HEADING', "Изменить форму Получатели");
define('FORM_RECIPIENTS_EDIT_FORM_RECIPIENTS_BTN', "Изменить форму Получатели");
// Console Text:
define('FORM_RECIPIENTS_FORM_PAGE', "Форма страницы");
define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "Вы можете установить более одного получателя, разделяя письма с запятыми.");
// Popup Messages:
define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "Сохранение получателя ...");
define('VIEW_FORM_TABLES_HEADING', "Просмотр таблиц формы");
define('VIEW_FORM_TABLES_BTN', "Просмотр таблиц формы");
define('VIEW_FORM_TABLES_SELECT_TABLE', "Выберите таблицы для просмотра");
define('VIEW_FORM_TABLES_FILTER_READ', "Фильтровать сообщения для чтения");
?>